@@ -35,22 +35,22 @@ ExpressionParser::~ExpressionParser()
 
 QString funcToTag(const QString& name)
 {
-	if(Analitza::Operator::toOperatorType(name)!=Analitza::Operator::none)
-		return QString("<%1 />").arg(name);
-	else
-		return "<ci type='function'>"+name+"</ci>";
+    if(Analitza::Operator::toOperatorType(name)!=Analitza::Operator::none)
+        return QStringLiteral("<%1 />").arg(name);
+    else
+        return "<ci type='function'>"+name+"</ci>";
 }
 
 void ExpressionParser::reallocateStack()
 {
-	int size = m_stateStack.size();
-	if (size == 0)
-		size = 128;
-	else
-		size <<= 1;
+    int size = m_stateStack.size();
+    if (size == 0)
+        size = 128;
+    else
+        size <<= 1;
 
-	m_symStack.resize(size);
-	m_stateStack.resize(size);
+    m_symStack.resize(size);
+    m_stateStack.resize(size);
 }
 
 bool ExpressionParser::parse(AbstractLexer *lexer)
@@ -67,17 +67,17 @@ bool ExpressionParser::parse(AbstractLexer *lexer)
       const int state = m_stateStack.at(m_tos);
       if (yytoken == -1 && - TERMINAL_COUNT != action_index [state]) {
         yytoken = lexer->lex();
-		while(yytoken==tComment) {
-			//TODO: Add mathml comment
-			m_comments.append(lexer->current.val);
-			yytoken = lexer->lex();
-		}
-		
-		if(!lexer->error().isEmpty()) {
-			m_err += lexer->error();
-			return false;
-		}
-	  }
+        while(yytoken==tComment) {
+            //TODO: Add mathml comment
+            m_comments.append(lexer->current.val);
+            yytoken = lexer->lex();
+        }
+        
+        if(!lexer->error().isEmpty()) {
+            m_err += lexer->error();
+            return false;
+        }
+      }
       int act = t_action (state, yytoken);
       if (act == ACCEPT_STATE)
         return true;
@@ -100,8 +100,8 @@ bool ExpressionParser::parse(AbstractLexer *lexer)
 #line 212 "exp.g"
 
 case 2:
-	m_exp = "<math>"+sym(1)+"</math>";
-	break;
+    m_exp = "<math>"+sym(1)+"</math>";
+    break;
 
 #line 218 "exp.g"
  case 3: sym(1) = "<declare><ci>"+sym(1)+"</ci>"+sym(3)+"</declare>"; break; 
@@ -114,26 +114,26 @@ case 2:
 #line 225 "exp.g"
 
 case 7:
-	sym(1) = lexer->current.val;
-	break;
+    sym(1) = lexer->current.val;
+    break;
 
 #line 234 "exp.g"
 
 case 10:
-	sym(1) = "<ci>"+sym(1)+"</ci>";
-	break;
+    sym(1) = "<ci>"+sym(1)+"</ci>";
+    break;
 
 #line 243 "exp.g"
 
 case 13:
-	sym(1) = "<apply><selector />"+sym(3)+sym(1)+"</apply>";
-	break;
+    sym(1) = "<apply><selector />"+sym(3)+sym(1)+"</apply>";
+    break;
 
 #line 250 "exp.g"
 
 case 14:
-	sym(1) = sym(2);
-	break;
+    sym(1) = sym(2);
+    break;
 
 #line 260 "exp.g"
  case 19: sym(1)=sym(2); break; 
@@ -152,50 +152,50 @@ case 14:
 #line 275 "exp.g"
 
 case 29:
-	sym(1).prepend(sym(3));
-	break;
+    sym(1).prepend(sym(3));
+    break;
 
 #line 282 "exp.g"
 
 case 30:
-	sym(1)=sym(3)+sym(5)+sym(1);
-	break;
+    sym(1)=sym(3)+sym(5)+sym(1);
+    break;
 
 #line 289 "exp.g"
 
 case 31:
-	sym(1)=sym(3)+"<domainofapplication>"+sym(5)+"</domainofapplication>"+sym(1);
-	break;
+    sym(1)=sym(3)+"<domainofapplication>"+sym(5)+"</domainofapplication>"+sym(1);
+    break;
 
 #line 297 "exp.g"
 
 case 32:
-	sym(1) = '<'+sym(1)+" />";
-	break;
+    sym(1) = '<'+sym(1)+" />";
+    break;
 
 #line 304 "exp.g"
 
 case 33:
-	sym(1) = '<'+sym(1)+'>'+sym(3)+"</"+sym(1)+'>';
-	break;
+    sym(1) = '<'+sym(1)+'>'+sym(3)+"</"+sym(1)+'>';
+    break;
 
 #line 312 "exp.g"
 
 case 34:
-	sym(1) = "<lambda>"+sym(1)+sym(3)+"</lambda>";
-	break;
+    sym(1) = "<lambda>"+sym(1)+sym(3)+"</lambda>";
+    break;
 
 #line 320 "exp.g"
 
 case 35:
-	sym(1) = "<apply><minus />"+sym(2)+"</apply>";
-	break;
+    sym(1) = "<apply><minus />"+sym(2)+"</apply>";
+    break;
 
 #line 327 "exp.g"
 
 case 36:
-	sym(1) = "<otherwise>"+sym(2)+"</otherwise>";
-	break;
+    sym(1) = "<otherwise>"+sym(2)+"</otherwise>";
+    break;
 
 #line 334 "exp.g"
  case 37: sym(1) = "<apply><plus />"  +sym(1)+sym(3)+"</apply>"; break; 
@@ -228,87 +228,87 @@ case 36:
 #line 353 "exp.g"
 
 case 52:
-	sym(1) += sym(3);
-	break;
+    sym(1) += sym(3);
+    break;
 
 #line 362 "exp.g"
 
 case 54:
-	sym(1) = sym(2);
-	break;
+    sym(1) = sym(2);
+    break;
 
 #line 369 "exp.g"
 
 case 55:
-	sym(1) = "<bvar><ci>"+sym(1)+"</ci></bvar>";
-	break;
+    sym(1) = "<bvar><ci>"+sym(1)+"</ci></bvar>";
+    break;
 
 #line 376 "exp.g"
 
 case 56:
-	sym(1) += sym(3);
-	break;
+    sym(1) += sym(3);
+    break;
 
 #line 383 "exp.g"
 
 case 57:
-	sym(1) += sym(3);
-	break;
+    sym(1) += sym(3);
+    break;
 
 #line 390 "exp.g"
 
 case 58:
-	sym(1) = "<uplimit>"+sym(3)+"</uplimit><downlimit>"+sym(1)+"</downlimit>";
-	break;
+    sym(1) = "<uplimit>"+sym(3)+"</uplimit><downlimit>"+sym(1)+"</downlimit>";
+    break;
 
 #line 396 "exp.g"
 
-		} // switch
-		m_stateStack[m_tos] = nt_action(act, lhs[r] - TERMINAL_COUNT);
-	} else {
-		int ers = state;
-		int shifts = 0;
-		int reduces = 0;
-		int expected_tokens[3];
-		for (int tk = 0; tk < TERMINAL_COUNT; ++tk) {
-			int k = t_action(ers, tk);
+        } // switch
+        m_stateStack[m_tos] = nt_action(act, lhs[r] - TERMINAL_COUNT);
+    } else {
+        int ers = state;
+        int shifts = 0;
+        int reduces = 0;
+        int expected_tokens[3];
+        for (int tk = 0; tk < TERMINAL_COUNT; ++tk) {
+            int k = t_action(ers, tk);
 
-			if (! k)
-				continue;
-			else if (k < 0)
-				++reduces;
-			else if (spell[tk]) {
-				if (shifts < 3)
-				expected_tokens[shifts] = tk;
-				++shifts;
-			}
-		}
+            if (! k)
+                continue;
+            else if (k < 0)
+                ++reduces;
+            else if (spell[tk]) {
+                if (shifts < 3)
+                expected_tokens[shifts] = tk;
+                ++shifts;
+            }
+        }
 
-		m_errorLineNumber = lexer->lineNumber();
-		int tokFoundType=lexer->current.type;
-		QString error;
-		
-		if (shifts && shifts<3) {
-			QString tokFound(spell[tokFoundType]);
-			QStringList expectedTokens;
-			for (int s = 0; s < shifts; ++s) {
-				expectedTokens += '\''+QLatin1String(spell[expected_tokens[s]])+'\'';
-			}
-			error=QCoreApplication::translate("error message", "Expected %1 instead of '%2'").arg(expectedTokens.join(QCoreApplication::tr(", ")), tokFound);
-		} else if(tokFoundType==tLpr) {
-			error=QCoreApplication::tr("Missing right parenthesis");
-		} else if(tokFoundType==tRpr || tokFoundType==tRcb) {
-			error=QCoreApplication::tr("Unbalanced right parenthesis");
-		} else
-			if(tokFoundType==tId)
-				error=QCoreApplication::tr("Unexpected token identifier: %1").arg(lexer->current.val);
-			else
-				error=QCoreApplication::tr("Unexpected token %1").arg(spell[tokFoundType]);
-		m_err.append(error);
-		return false;
-		}
-	}
+        m_errorLineNumber = lexer->lineNumber();
+        int tokFoundType=lexer->current.type;
+        QString error;
+        
+        if (shifts && shifts<3) {
+            QString tokFound(spell[tokFoundType]);
+            QStringList expectedTokens;
+            for (int s = 0; s < shifts; ++s) {
+                expectedTokens += '\''+QLatin1String(spell[expected_tokens[s]])+'\'';
+            }
+            error=QCoreApplication::translate("error message", "Expected %1 instead of '%2'").arg(expectedTokens.join(QCoreApplication::tr(", ")), tokFound);
+        } else if(tokFoundType==tLpr) {
+            error=QCoreApplication::tr("Missing right parenthesis");
+        } else if(tokFoundType==tRpr || tokFoundType==tRcb) {
+            error=QCoreApplication::tr("Unbalanced right parenthesis");
+        } else
+            if(tokFoundType==tId)
+                error=QCoreApplication::tr("Unexpected token identifier: %1").arg(lexer->current.val);
+            else
+                error=QCoreApplication::tr("Unexpected token %1").arg(spell[tokFoundType]);
+        m_err.append(error);
+        return false;
+        }
+    }
 
-	return false;
+    return false;
 }
 
