@@ -110,7 +110,7 @@ Object* ProvideDerivative::derivateContent##T(const T * v)\
     return ret;\
 }
 
-ITERATE(List)
+ITERATE(List, {})
 ITERATE(Vector, v->size())
 
 Object* ProvideDerivative::derivativeApply(const Apply* c)
