@@ -20,6 +20,7 @@
 #define OPERATORSMODEL_H
 
 #include <QAbstractTableModel>
+#include <QSharedPointer>
 #include "analitzaguiexport.h"
 
 namespace Analitza
@@ -28,10 +29,17 @@ class Variables;
 class Operator;
 }
 
+//TODO: get in the namespace
 /** Operators model is a model class that has a relation of all operators string with their OperatorType. */
 class ANALITZAGUI_EXPORT OperatorsModel : public QAbstractTableModel
 {
+    Q_OBJECT
     public:
+        enum Roles {
+            IsVariableRole = Qt::UserRole + 1,
+            DescriptionRole
+        };
+
         /** Constructor. Creates a new Operator Model. */
         explicit OperatorsModel(QObject *parent=0);
         
@@ -43,25 +51,29 @@ class ANALITZAGUI_EXPORT OperatorsModel : public QAbstractTableModel
         
         static QString example(const Analitza::Operator& o);
         
+        QHash<int, QByteArray> roleNames() const override;
+
         /** Adds an entry to the model. */
     //     void addEntry(int i, const QString&, const QString&, const QString& ex=QString());
         
         /** Updates the variables information */
         void updateInformation();
         
-        QVariant data( const QModelIndex &index, int role=Qt::DisplayRole) const;
-        QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const;
-        int rowCount(const QModelIndex &parent=QModelIndex()) const;
-        int columnCount(const QModelIndex &parent=QModelIndex()) const;
+        QVariant data( const QModelIndex &index, int role=Qt::DisplayRole) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role=Qt::DisplayRole) const override;
+        int rowCount(const QModelIndex &parent=QModelIndex()) const override;
+        int columnCount(const QModelIndex &parent=QModelIndex()) const override;
         
-        void setVariables(const Analitza::Variables* v) { m_vars=v; }
+        void setVariables(const QSharedPointer<Analitza::Variables> &v) { m_vars=v; }
         QModelIndex indexForOperatorName(const QString& id) const;
         QString parameterHelp(const QModelIndex& idx, int param, bool inbounds) const;
         static QString standardFunctionCallHelp(const QString& funcname, int param, int paramcount, bool inbounds, bool isbounded);
         
+        Q_SCRIPTABLE static QString lastWord(int pos, const QString &exp);
         
     private:
-        const Analitza::Variables *m_vars;
+        QSharedPointer<Analitza::Variables> m_vars;
 };
 
+
 #endif
