@@ -55,13 +55,13 @@ public:
     PlotsModel(QObject * parent = 0);
     virtual ~PlotsModel();
 
-    virtual Qt::ItemFlags flags(const QModelIndex & index) const;
-    virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-    virtual QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const;
-    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole); // only title and check=visible
-    virtual int rowCount(const QModelIndex & parent = QModelIndex()) const;
-    virtual int columnCount(const QModelIndex& parent) const;
-    virtual bool removeRows(int row, int count, const QModelIndex & parent = QModelIndex());
+    virtual Qt::ItemFlags flags(const QModelIndex & index) const override;
+    virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    virtual QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const override;
+    virtual bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override; // only title and check=visible
+    virtual int rowCount(const QModelIndex & parent = QModelIndex()) const override;
+    virtual int columnCount(const QModelIndex& parent) const override;
+    virtual bool removeRows(int row, int count, const QModelIndex & parent = QModelIndex()) override;
     QHash<int, QByteArray> roleNames() const override;
 
     void addPlot(PlotItem *it);
@@ -78,7 +78,7 @@ public:
     /**
      * Helper method to help easily add elements to the model
      */
-    QStringList addFunction(const QString& expression, Analitza::Dimension dim, Analitza::Variables* vars);
+    Q_SCRIPTABLE QStringList addFunction(const QString& expression, Analitza::Dimension dim, const QSharedPointer<Analitza::Variables>& vars);
 
 protected:
     void emitChanged(PlotItem* it);
