@@ -102,7 +102,7 @@ void Graph2DMobile::translate(qreal x, qreal y)
     moveViewport(QPoint(x,y));
 }
 
-QStringList Graph2DMobile::addFunction(const QString& expression, Analitza::Variables* vars)
+QStringList Graph2DMobile::addFunction(const QString& expression, const QSharedPointer<Analitza::Variables>& vars)
 {
     PlotsModel* plotsmodel = qobject_cast<PlotsModel*>(model());
     if(!plotsmodel)
@@ -146,3 +146,16 @@ QSGNode* Graph2DMobile::updatePaintNode(QSGNode* node, QQuickItem::UpdatePaintNo
     n->setRect(boundingRect());
     return n;
 }
+
+QStringList Graph2DMobile::filters() const
+{
+    return {QObject::tr("PNG Image (*.png)")};
+}
+
+bool Graph2DMobile::save(const QUrl& url) const
+{
+    if(!url.isLocalFile())
+        return false;
+
+    return m_buffer.save(url.toLocalFile());
+}
