@@ -32,13 +32,14 @@ class Graph2DMobile : public QQuickItem, public Analitza::Plotter2D
 {
     Q_OBJECT
     Q_PROPERTY(QAbstractItemModel* model READ model WRITE setModel)
-    Q_PROPERTY(QRectF viewport READ lastViewport WRITE setViewport)
-    Q_PROPERTY(bool showGrid READ showGrid WRITE setShowGrid)
+    Q_PROPERTY(QRectF viewport READ lastViewport WRITE setViewport RESET resetViewport)
+    Q_PROPERTY(bool showGrid READ showGrid WRITE setShowGrid NOTIFY showGridChanged)
     Q_PROPERTY(bool showMinorGrid READ showMinorGrid WRITE setShowMinorGrid)
     Q_PROPERTY(bool keepAspectRatio READ keepAspectRatio WRITE setKeepAspectRatio)
     Q_PROPERTY(bool currentFunction READ currentFunction WRITE setCurrentFunction)
     Q_PROPERTY(bool ticksShown READ ticksShownAtAll WRITE setTicksShownAtAll)
     Q_PROPERTY(bool minorTicksShown READ minorTicksShown WRITE setShowMinorTicks)
+    Q_PROPERTY(QStringList filters READ filters CONSTANT)
     public:
         Graph2DMobile(QQuickItem* parent = 0);
         
@@ -47,24 +48,30 @@ class Graph2DMobile : public QQuickItem, public Analitza::Plotter2D
         virtual void modelChanged() override;
         virtual int currentFunction() const override { return m_currentFunction; }
         
-        void geometryChanged(const QRectF& newGeometry, const QRectF& oldGeometry) override /*Q_OVERRIDE*/;
-        QSGNode* updatePaintNode(QSGNode*, UpdatePaintNodeData*) override /*Q_OVERRIDE*/;
+        void geometryChanged(const QRectF& newGeometry, const QRectF& oldGeometry) override;
+        QSGNode* updatePaintNode(QSGNode*, UpdatePaintNodeData*) override;
         
         void setCurrentFunction(int f) { m_currentFunction = f; }
         bool ticksShownAtAll() const { return ticksShown()!=0; }
         void setTicksShownAtAll(bool shown);
         
+        QStringList filters() const;
+
     public Q_SLOTS:
         void translate(qreal x, qreal y);
         void scale(qreal s, int x, int y);
         void resetViewport();
-        QStringList addFunction(const QString& expression, Analitza::Variables* vars=0);
+        QStringList addFunction(const QString& expression, const QSharedPointer<Analitza::Variables>& vars = {});
+        bool save(const QUrl &url) const;
         
     private Q_SLOTS:
         void updateFuncs(const QModelIndex& start, const QModelIndex& end);
         void addFuncs(const QModelIndex& parent, int start, int end);
         void removeFuncs(const QModelIndex& parent, int start, int end);
         
+    Q_SIGNALS:
+        void showGridChanged() override;
+
     private:
         void paint();
 
